<?php

/**
 * @file
 * salsaIndexable class used to index content
 */

class SalsaIndexable {

  private $document;

  /**
   * Constructor for a salsaIndexable class,
   *
   * @param integer|string $uid
   *   The document unique identifier.
   */
  public function __construct($uid) {
    $this->document = new DOMDocument('1.0', 'utf-8');
    $indexable = $this->document->createElement('indexable');
    $indexable->setAttribute('uid', $uid);
    $this->document->appendChild($indexable);
  }

  /**
   * Creates a new XML node to store content.
   *
   * @param integer $cid
   *   The content unique identifier.
   * @param string $value
   *   The content value.
   */
  public function addContent($cid, $value) {
    $content = $this->document->createElement('content');
    $cdata = $this->document->createCDATASection($value);
    $content->setAttribute('cid', $cid);
    $content->appendChild($cdata);
    $this->document->documentElement->appendChild($content);
  }

  /**
   * Creates a new XML node to store metadata.
   *
   * @param string $key
   *   The key identifier for this metadata
   * @param string $metadata
   *   The metadata value
   */
  public function addMetadata($key, $metadata) {
    $metadata = $this->document->createElement('metadata', $metadata);
    $metadata->setAttribute('key', $key);
    $this->document->documentElement->appendChild($metadata);
  }

  /**
   * Helper function to get xml code
   *
   * @return string
   *   The indexable xml string
   */
  public function asXML() {
    return $this->document->saveXML();
  }

}
